import requests

class SmartcarException(Exception):
    def __init__(self, response):
        self.message = 'Unknown error'
        if type(response) is requests.models.Response:
            json = response.json()
            self.request_id = response.headers.get('sc-request-id')
            if 'message' in json:
                self.message = json['message']
            elif 'error_description' in json:
                self.message = json['error_description']
        elif type(response) is str:
            self.message = response

    def __str__(self):
        return self.message


class ValidationException(SmartcarException):
    pass


class AuthenticationException(SmartcarException):
    pass


class PermissionException(SmartcarException):
    pass


class ResourceNotFoundException(SmartcarException):
    pass


class StateException(SmartcarException):
    def __init__(self, response):
        super(StateException, self).__init__(response)
        json = response.json()
        self.code = json['code']

    def __str__(self):
        return self.code + ': ' + self.message


class RateLimitingException(SmartcarException):
    pass


class MonthlyLimitExceeded(SmartcarException):
    pass


class ServerException(SmartcarException):
    pass


class VehicleNotCapableException(SmartcarException):
    pass


class SmartcarNotCapableException(SmartcarException):
    pass


class GatewayTimeoutException(SmartcarException):
    def __init__(self, response):
        self.message = response.text

    def __str__(self):
        return self.message



from setuptools import setup
import re

def _get_version():
  """Extract version from package."""
  with open('smartcar/__init__.py') as reader:
    match = re.search(
      r'^__version__\s*=\s*[\'"]([^\'"]*)[\'"]',
      reader.read(),
      re.MULTILINE
    )
    if match:
      return match.group(1)
    else:
      raise RuntimeError('Unable to extract version.')

def _get_long_description():
  """Get README contents."""
  with open('README.md') as reader:
    return reader.read()

setup(
    name='smartcar',
    version=_get_version(),
    description='Smartcar Python SDK',
    long_description=_get_long_description(),
    long_description_content_type='text/markdown',
    author='Smartcar',
    author_email='hello@smartcar.com',
    packages=['smartcar'],
    url='https://github.com/smartcar/python-sdk',
    license='MIT',
    install_requires=[
        'python-dateutil',
        'requests',
    ],
    extras_require={
        'dev': [
            'coverage',
            'nose',
            'mock',
            'responses',
            'selenium',
            'retrying',
        ]
    }
)



__version__ = '5.0.0'

from .smartcar import (AuthClient, is_expired, get_user_id, get_vehicle_ids)
from .vehicle import Vehicle
from .exceptions import (
    SmartcarException,
    ValidationException,
    AuthenticationException,
    PermissionException,
    ResourceNotFoundException,
    StateException,
    RateLimitingException,
    MonthlyLimitExceeded,
    ServerException,
    VehicleNotCapableException,
    SmartcarNotCapableException,
    GatewayTimeoutException)
